import React, { useState } from 'react';
import { Button, Form, Modal, Table } from 'react-bootstrap';
import { useDispatch, useSelector } from 'react-redux';
import { algorithmsActions, selectAlgorithms } from '../redux/slices/algorithmsSlice';
import { TableFileInputs } from './TableFileInputs';
import { TablePositionalInputs } from './TablePositionalInputs';
import { registerAlgorithm } from '../utils/algoConfig';
import AsyncSelect from 'react-select/async';
import { getResources } from "../utils/api";
export const RegistrationForm = () => {
    // Local state variables
    const [firstStep, setFirstStep] = useState(true);
    // const [validRepo, setValidRepo] = useState(false)
    const [validRepo, setValidRepo] = useState(true);
    const [repoBranches, setRepoBranches] = useState([]);
    const [firstRepoCheck, setFirstRepoCheck] = useState(true);
    const [show, setShow] = useState(false);
    const [showSpinner, setShowSpinner] = useState(false);
    // Redux
    const dispatch = useDispatch();
    const { registrationUrl, repoRunCommand, algoResource } = useSelector(selectAlgorithms);
    const { setAlgoDesc, setAlgoDiskSpace, setAlgoName, setAlgoResource, setAlgoContainerURL, setRepoBranch, setRepoRunCommand, setRepoBuildCommand, setRepoUrl } = algorithmsActions;
    // useEffect(() => {
    //     if (!show) {
    //         handleModalShow()
    //     }
    // }, [registrationUrl]);
    const validateRepo = (e) => {
        // document.body.style.cursor = 'wait'
        e.target.value.length == 0 ? setValidRepo(false) : setValidRepo(true);
        //let branches = getRepoInfo()
        //branches.length == 0 ? setValidRepo(false) : setValidRepo(true); setRepoBranches(branches);
        //setRepoUrl(e.target.value)
        setFirstRepoCheck(false);
    };
    const handleKeyPress = (e) => {
        if (e.keyCode === 13) {
            e.target.blur();
        }
    };
    const handleAlgoNameChange = e => {
        dispatch(setAlgoName(e.target.value));
    };
    const handleRepoUrlChange = e => {
        dispatch(setRepoUrl(e.target.value));
    };
    const handleBranchChange = e => {
        dispatch(setRepoBranch(e.target.value));
    };
    const handleRunCmdChange = e => {
        dispatch(setRepoRunCommand(e.target.value));
    };
    const handleBuildCmdChange = e => {
        dispatch(setRepoBuildCommand(e.target.value));
    };
    const handleAlgoDescChange = e => {
        dispatch(setAlgoDesc(e.target.value));
    };
    const handleDiskSpaceChange = e => {
        dispatch(setAlgoDiskSpace(e.target.value));
    };
    const handleResourceChange = value => {
        dispatch(setAlgoResource(value));
    };
    const handleContainerURLChange = e => {
        dispatch(setAlgoContainerURL(e.target.value));
    };
    const handleModalClose = () => setShow(false);
    const handleModalShow = () => setShow(true);
    async function submitHandler(e) {
        e.preventDefault();
        // setShowSpinner(true)
        let res = await registerAlgorithm();
        if (res) {
            // setShowSpinner(false)
            handleModalShow();
        }
    }
    return (React.createElement(React.Fragment, null,
        React.createElement(Form, { onSubmit: submitHandler },
            React.createElement("div", { className: 'section-padding' },
                React.createElement("h2", null, "Repository Information"),
                React.createElement("span", { className: firstStep ? 'show content-padding' : 'hide content-padding' }, "To register an algorithm to the MAAP, your code must be committed to a public code repository."),
                React.createElement(Table, { className: "form-table" },
                    React.createElement("tbody", null,
                        React.createElement("tr", null,
                            React.createElement("td", null, "Repository URL"),
                            React.createElement("td", { className: 'flex' },
                                React.createElement("div", null,
                                    React.createElement("div", { className: 'flex' },
                                        React.createElement(Form.Control, { disabled: !firstStep, onChange: handleRepoUrlChange, onKeyDown: handleKeyPress, onBlur: validateRepo, type: "text", placeholder: "Enter repository URL" }),
                                        React.createElement("div", { className: firstStep ? firstRepoCheck ? 'hide' : 'show' : 'hide' })),
                                    React.createElement("div", { className: firstStep ? firstRepoCheck ? 'hide' : 'show' : 'hide' })))),
                        React.createElement("tr", null,
                            React.createElement("td", null, "Repository Branch"),
                            React.createElement("td", null,
                                React.createElement(Form.Control, { disabled: !firstStep, type: "text", placeholder: "Enter repository branch...", onChange: handleBranchChange }))),
                        React.createElement("tr", null,
                            React.createElement("td", null, "Run Command"),
                            React.createElement("td", null,
                                React.createElement(Form.Control, { disabled: !firstStep, type: "text", placeholder: "Enter run command...", onChange: handleRunCmdChange }))),
                        React.createElement("tr", null,
                            React.createElement("td", null, "Build Command"),
                            React.createElement("td", null,
                                React.createElement(Form.Control, { disabled: !firstStep, type: "text", placeholder: "Enter build command...", onChange: handleBuildCmdChange }))))),
                React.createElement("span", { className: firstStep ? 'show' : 'hide' },
                    React.createElement(Button, { disabled: !validRepo, onClick: () => { validRepo ? setFirstStep(false) : ""; } }, "Add General Information"))),
            React.createElement("div", { className: firstStep ? 'hide section-padding' : 'show section-padding' },
                React.createElement("h2", null, "General Information"),
                React.createElement(Table, { className: "form-table" },
                    React.createElement("tbody", null,
                        React.createElement("tr", null,
                            React.createElement("td", null, "Algorithm Name"),
                            React.createElement("td", null,
                                React.createElement(Form.Control, { type: "text", placeholder: "Enter algorithm name", onChange: handleAlgoNameChange }))),
                        React.createElement("tr", null,
                            React.createElement("td", null, "Algorithm Description"),
                            React.createElement("td", null,
                                React.createElement(Form.Control, { type: "textarea", placeholder: "Enter algorithm description", onChange: handleAlgoDescChange }))),
                        React.createElement("tr", null,
                            React.createElement("td", null, "Disk Space (GB)"),
                            React.createElement("td", null,
                                React.createElement(Form.Control, { type: "text", placeholder: "Enter disk space", onChange: handleDiskSpaceChange }))),
                        React.createElement("tr", null,
                            React.createElement("td", null, "Resource Allocation"),
                            React.createElement("td", null,
                                React.createElement(Form.Group, { className: "mb-3 algorithm-input" },
                                    React.createElement(AsyncSelect, { cacheOptions: true, defaultOptions: true, value: algoResource, loadOptions: getResources, onChange: handleResourceChange, placeholder: "Select resource" })))),
                        React.createElement("tr", null,
                            React.createElement("td", null, "Container URL"),
                            React.createElement("td", null,
                                React.createElement(Form.Control, { type: "text", placeholder: "Enter container URL", onChange: handleContainerURLChange }))))),
                React.createElement("div", { className: 'section-padding' },
                    React.createElement("h2", null, "Input Types"),
                    React.createElement(TableFileInputs, null),
                    React.createElement(TablePositionalInputs, null)),
                React.createElement(Button, { variant: "primary", type: "submit" }, "Register Algorithm"))),
        React.createElement("div", null,
            React.createElement(Modal, { show: show, "aria-labelledby": "contained-modal-title-vcenter", onHide: handleModalClose },
                React.createElement(Modal.Header, { closeButton: true },
                    React.createElement(Modal.Title, null, "Algorithm submitted for registration")),
                React.createElement(Modal.Body, null,
                    "Your algorithm was submitted for registration. You can view the progress here: ",
                    React.createElement("a", { href: registrationUrl }, registrationUrl)),
                React.createElement(Modal.Footer, null,
                    React.createElement(Button, { variant: "primary", onClick: handleModalClose }, "Close"))))));
};
//# sourceMappingURL=RegistrationForm.js.map