import React from 'react';
import { Table } from 'react-bootstrap';
import { BsPlusCircleFill, BsInfoCircle } from 'react-icons/bs';
import { useDispatch, useSelector } from 'react-redux';
import { algorithmsActions, selectAlgorithms } from '../redux/slices/algorithmsSlice';
import { ALGO_INPUTS_DESC, ALGO_INPUT_FIELDS } from '../constants';
import { InputRow } from './InputRow';
import { EmptyRow } from './EmptyRow';
import { Tooltip as ReactTooltip } from "react-tooltip";
export const TableConfigInputs = () => {
    // Redux
    const dispatch = useDispatch();
    const { configData, inputId } = useSelector(selectAlgorithms);
    const { addConfigData, updateConfigData, removeConfigData, incrementInputId } = algorithmsActions;
    const addRow = () => {
        dispatch(addConfigData({ [ALGO_INPUT_FIELDS.INPUT_NAME]: "",
            [ALGO_INPUT_FIELDS.INPUT_DEFAULT]: "",
            [ALGO_INPUT_FIELDS.INPUT_DESC]: "",
            [ALGO_INPUT_FIELDS.IS_REQUIRED]: false,
            [ALGO_INPUT_FIELDS.INPUT_ID]: inputId }));
        dispatch(incrementInputId());
    };
    const handleDataChange = e => {
        switch (e.target.type) {
            case "checkbox": {
                dispatch(updateConfigData({ inputId: e.target.parentNode.parentNode.parentNode.id, inputField: [e.target.id], inputValue: e.target.checked }));
                break;
            }
            default:
                dispatch(updateConfigData({ inputId: e.target.parentNode.parentNode.id, inputField: [e.target.id], inputValue: e.target.value }));
                break;
        }
    };
    const handleRemoveRow = (inputId) => {
        dispatch(removeConfigData({ key: inputId }));
    };
    return (React.createElement("div", null,
        React.createElement("div", { className: "input-types" },
            React.createElement("h4", null, "Configuration Inputs"),
            React.createElement(ReactTooltip, { anchorId: "config_input_info", place: "right", variant: "dark", content: ALGO_INPUTS_DESC.CONFIGURATION_INPUTS }),
            React.createElement("span", { id: "config_input_info" },
                React.createElement(BsInfoCircle, null))),
        React.createElement(Table, { className: "inputs-table" },
            React.createElement("thead", null,
                React.createElement("tr", null,
                    React.createElement("td", null,
                        React.createElement(BsPlusCircleFill, { className: "success-icon", onClick: addRow })),
                    React.createElement("td", null, "Name"),
                    React.createElement("td", null, "Description"),
                    React.createElement("td", { className: "center-align" }, "Required?"),
                    React.createElement("td", null, "Default Value"),
                    React.createElement("td", null))),
            React.createElement("tbody", null, configData.length == 0 ? React.createElement(EmptyRow, { text: "No inputs specified" }) : Object.entries(configData).map(([key, data]) => {
                console.log(data);
                return React.createElement(InputRow, { row: data, handleRemoveRow: handleRemoveRow, handleDataChange: handleDataChange });
            })))));
};
//# sourceMappingURL=TableConfigInputs.js.map